@@ -24,7 +24,7 @@ import static org.eclipse.equinox.p2.tests.publisher.actions.StatusMatchers.stat
 import static org.hamcrest.CoreMatchers.containsString;
 import static org.hamcrest.CoreMatchers.hasItem;
 import static org.hamcrest.CoreMatchers.is;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 
 import java.io.BufferedInputStream;
 import java.io.File;
